// ------------------------------------
// Filename      : LongLatPosition.java
// Author        : Sven Maerivoet
// Last modified : 06/07/2022
// Target        : Java VM (1.8)
// ------------------------------------

/**
 * Copyright 2003-2022 Sven Maerivoet
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.sm.smtools.math;

/**
 * The <CODE>LongLatPosition</CODE> class provides a data container for a (longitude,latitude) position.
 * <P>
 * <B>Note that this class cannot be subclassed!</B>
 *
 * @author  Sven Maerivoet
 * @version 06/07/2022
 */
public final class LongLatPosition
{
	// internal datastructures
	private double fLongitude;
	private double fLatitude;

	/****************
	 * CONSTRUCTORS *
	 ****************/

	/**
	 * Constructs a <CODE>LongLatPosition</CODE> object with the specified (longitude,latitude) coordinates.
	 * 
	 * @param longitude  -
	 * @param latitude   -
	 */
	public LongLatPosition(double longitude, double latitude)
	{
		fLongitude = longitude;
		fLatitude = latitude;
	}

	/**
	 * Constructs a <CODE>LongLatPosition</CODE> object with zero-coordinates.
	 */
	public LongLatPosition()
	{
	}

	/******************
	 * PUBLIC METHODS *
	 ******************/

	/**
	 * Gets the position's longitude.
	 * 
	 * @return the position's longitude
	 */
	public double getLongitude()
	{
		return fLongitude;
	}

	/**
	 * Sets the position's longitude.
	 * 
	 * @param longitude  -
	 */
	public void setLongitude(double longitude)
	{
		fLongitude = longitude;
	}

	/**
	 * Gets the position's latitude.
	 * 
	 * @return the position's latitude
	 */
	public double getLatitude()
	{
		return fLatitude;
	}

	/**
	 * Sets the position's latitude.
	 * 
	 * @param latitude  -
	 */
	public void setLatitude(double latitude)
	{
		fLatitude = latitude;
	}
}
